@@ -5,7 +5,7 @@ package WebService::Backlog;
 use strict;
 use 5.008001;
 
-our $VERSION = '0.07';
+our $VERSION = '0.08';
 
 use Carp;
 use RPC::XML::Client;
@@ -226,8 +226,7 @@ sub updateIssue {
               . ref($arg)
               . ']' );
     }
-    croak("key must be specified.")     unless ( $issue->key );
-    croak("summary must be specified.") unless ( $issue->summary );
+    croak("key must be specified.") unless ( $issue->key );
 
     my $req = RPC::XML::request->new( 'backlog.updateIssue', $issue->hash );
     my $res = $self->{client}->send_request($req);
@@ -296,7 +295,7 @@ WebService::Backlog - Perl interface to Backlog.
 =head1 DESCRIPTION
 
 WebService::Backlog provides interface to Backlog.
-Backlog is a web based project collaboration tool.
+Backlog is a web based project collaboration & communication tool.
 
 For more information on Backlog, visit the Backlog website. http://www.backlog.jp/
 
@@ -304,30 +303,180 @@ For more information on Backlog, visit the Backlog website. http://www.backlog.j
 
 =head2 new
 
+Returns a new WebService::Backlog object.
+
+ my $backlog = WebService::Backlog->new(
+   space    => 'yourspaceid',
+   username => 'username',
+   password => 'password'
+ );
+
+Parameters below must be specified.
+
+ space    ... your space id
+ username ... your username in this space
+ password ... your passwrord
+
 =head2 getProjects
 
+Returns a list of all projects you join.
+
+ my $projects = $backlog->getProjects;
+
+This method returns a reference to array of WebService::Backlog::Project.
+
 =head2 getProject
 
+Retrieve a specific project by id or key.
+
+  my $project_by_id = $backlog->getProject(123);
+  my $project_by_key = $backlog->getProject("BLG");
+
 =head2 getComponents
 
+Returns a list of all components(categories) of project.
+
+  my $components = $backlog->getComponents( $project_id );
+
+This method returns a reference to array of WebService::Backlog::Component.
+
 =head2 getVersions
 
+Returns a list of all versions(milestones) of project.
+
+  my $versions = $backlog->getVersions( $project_id );
+
+This method returns a reference to array of WebService::Backlog::Version.
+
 =head2 getUsers
 
+Returns a list of all users who join this project.
+
+  my $users = $backlog->getUsers( $project_id );
+
+This method returns a reference to array of WebService::Backlog::User.
+
 =head2 getIssue
 
+Retrieve a specific issue by key or id.
+
+  my $issue_by_id = $backlog->getIssue( 123 );
+  my $issue_by_key = $backlog->getIssue( "BLG-11" );
+
 =head2 getComments
 
+Returns a list of all comments of this issue.
+
+  my $comments = $backlog->getComments( $issue_id );
+
+This method returns a reference to array of WebService::Backlog::Comment.
+
 =head2 countIssue
 
+Returns count of issues by condition.
+
+  my $issue_count = $backlog->countIssue( $condition );
+
+Argument C<$condition> is object of WebService::Backlog::FindCondition or reference of HASH.
+
+  # FindCondition
+  my $condition = WebService::Backlog::FindCondition->new({ projectId => 123, statusId => [1,2,3] });
+  my $count = $backlog->countIssue($condition);
+
+  # HASH condision
+  my $count_by_hash = $backlog->countIssue({ projectId => 123, statusId => [1,2,3] });
+
 =head2 findIssue
 
+Returns a list of issues by condition.
+
+  my $issues = $backlog->findIssue( $condition );
+
+Argument C<$condition> is object of WebService::Backlog::FindCondition or reference of HASH.
+
+  # FindCondition
+  my $condition = WebService::Backlog::FindCondition->new({ projectId => 123, statusId => [1,2,3] });
+  my $count = $backlog->countIssue($condition);
+
+  # HASH condision
+  my $count_by_hash = $backlog->countIssue({ projectId => 123, statusId => [1,2,3] });
+
 =head2 createIssue
 
+Create new issue.
+
+  my $issue = $backlog->createIssue( $create_issue );
+
+Argument C<$create_issue> is object of WebService::Backlog::CreateIssue or reference of HASH.
+
+  # CreateIssue
+  my $create_issue = WebService::Backlog::CreateIssue->new({
+    projectId   => 123,
+    summary     => 'This is new issue.',
+    description => 'This is new issue about ...',
+  });
+  my $issue = $backlog->createIssue($create_issue);
+
+  # HASH condision
+  my $issue_by_hash = $backlog->createIssue({
+    projectId   => 123,
+    summary     => 'This is new issue.',
+    description => 'This is new issue about ...',
+  });
+
 =head2 updateIssue
 
+Update a issue.
+
+  my $issue = $backlog->updateIssue( $update_issue );
+
+Argument C<$update_issue> is object of WebService::Backlog::UpdateIssue or reference of HASH.
+
+  # UpdateIssue
+  my $update_issue = WebService::Backlog::UpdateIssue->new({
+    key     => 'BLG-123',
+    comment => 'This is comment',
+  });
+  my $issue = $backlog->updateIssue($update_issue);
+
+  # HASH condision
+  my $issue_by_hash = $backlog->updateIssue({
+    key     => 'BLG-123',
+    comment => 'This is comment',
+  });
+
+Argument parameter 'key' is required.
+
 =head2 switchStatus
 
+Switch status of issue.
+
+  my $issue = $backlog->switchStatus( $switch_status );
+
+Argument C<$switch_status> is object of WebService::Backlog::SwitchStatus or reference of HASH.
+
+  # SwitchStatus
+  my $switch_status = WebService::Backlog::SwitchStatus->new({
+    key      => 'BLG-123',
+    statusId => 2,
+    comment  => 'I get to work',
+  });
+  my $issue = $backlog->switchStatus($switch_status);
+
+  # HASH condision
+  my $issue_by_hash = $backlog->switchStatus({
+    key      => 'BLG-123',
+    statusId => 2,
+    comment  => 'I get to work',
+  });
+
+Argument parameters 'key' and 'statusId' are required.
+
+statusId value means
+  1: Open
+  2: In Progress
+  3: Resolved
+  4: Closed
 
 =head1 AUTHOR
 
@@ -340,11 +489,17 @@ it under the same terms as Perl itself.
 
 =head1 SEE ALSO
 
-    Backlog : http://www.backlog.jp/
-Backlog API : http://www.backlog.jp/api/
+=over
 
-Source code : http://github.com/dragon3/webservice-backlog/tree/master
-              git://github.com/dragon3/webservice-backlog.git
+=item Backlog
+
+http://www.backlog.jp/
+
+=item Backlog API
+
+http://www.backlog.jp/api/
+
+=back
 
 =cut
 
